Documentation
¶
Overview ¶
Package parser provide html email parsers this package contains different email parsers for each newsletter mail each parser should be ablt to parse a specfic newsletter email's html Contents and return a list of articles, which can be conposed into rss feeds
Index ¶
Constants ¶
const (
// AylienAPIMaxConcurrentCount maximum concurrent api request count for aylien
AylienAPIMaxConcurrentCount = 5
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Analyzer ¶
type Analyzer interface {
Analyze([]Article)
}
Analyzer interface to provider analyze function for articles
func NewAylienAnalyzer ¶
NewAylienAnalyzer create an aylien analyzer
type Article ¶
type Article struct {
Title string
Link string
Summary string
Author string
PublishDate time.Time
Image string
Videos []string
Domain string
Content string
}
Article one article
type AylienAnalyzer ¶
type AylienAnalyzer struct {
AppID string
AppKey string
Client *textapi.Client
APIChannel chan struct{}
}
AylienAnalyzer analyzer using aylien api
func (*AylienAnalyzer) Analyze ¶
func (ay *AylienAnalyzer) Analyze(articles []Article)
Analyze use aylien api to extract each article and get summary of them
type DiscoverdevParser ¶
type DiscoverdevParser struct {
}
DiscoverdevParser mail parser for microservice weekly newsletter
type FeedItemParser ¶
func FindFeedParser ¶
func FindFeedParser(url, title string) (FeedItemParser, error)
FindFeedParser find proper html parser for the specified feed
type HackerNewsDigestParser ¶
type HackerNewsDigestParser struct {
}
MicroserviceParser mail parser for microservice weekly newsletter
type MicroserviceParser ¶
type MicroserviceParser struct {
}
MicroserviceParser mail parser for microservice weekly newsletter